//  Project       : Toolbox
//  Workpackage   : libASR 
//
//               Copyright (C) 2023, ...
//            Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
//                       German Aerospace Center
//
//       Institut fuer Flugfuehrung/Institute of Flight Guidance
//              Tel. +49 531 295 2501, Fax: +49 531 295 2550
//                 WWW: http://www.bs.dlr.de/FL/
//
//  These coded instructions, statements, and computer programs contain
//  unpublished proprietary information of the German Aerospace Center
//  and are protected by the copyright law. They may not be disclosed to
//  third parties or copied or duplicated in any form,in whole or in part,
//  without the prior written consent of the German Aerospace Center


/*!
\file C_String.h
\brief Emulation of class C_String outside DLR environment 
\author Hartmut Helmke (HHe)

\date 2023-07-08 HHe: first version

*/

#pragma once
#ifndef C_StringHeader
#define C_StringHeader
#include <vector>
#include <string>
using std::vector;
using std::string;

namespace libutil
{
   class C_String : public string
   {
   public:
      C_String(string str) : string(str) { ; }
      inline vector<string> split_V(const std::string& separator, bool skip_empty) const;
      inline static string trim(const string& s);
   };

   inline string C_String::trim(const string& s)
   {
      string res = "";
      size_t i = 0;
      while (i < s.length() && (s[i] == ' ' || s[i] == '\t' || s[i] == '\n' || s[i] == '\r')) { ++i; }
      if (i < s.length()) { // nicht leer
         size_t p = i; // erstes nicht whitespace Zeichen
         i = s.length() - 1;
         while (i > 0 && (s[i] == ' ' || s[i] == '\t' || s[i] == '\n' || s[i] == '\r')) { --i; }
         size_t len = i - p + 1; // Lnge bis inkl. letztes nicht whitespace Zeichen
         res = s.substr(p, len);
      }
      return res;
   }

   inline vector<string> C_String::split_V(const std::string& separator, bool skip_empty) const
   {
      string src = *this;
      size_t sepl = separator.length();
      vector<string> dest;
      string::size_type p = 0;
      string::size_type q = 0;
      string tmp;
      while ((q = src.find(separator, p)) != string::npos) {
         tmp = trim(src.substr(p, q - p));
         if (!(skip_empty && tmp.empty())) {
            dest.push_back(tmp);
         }
         p = q + sepl; // hinterm Komma weitermachen
      }
      // und den Rest
      tmp = trim(src.substr(p));
      if (!(skip_empty && tmp.empty())) {
         dest.push_back(tmp);
      }
      return dest;
   }
}

#endif /* C_StringHeader*/
