//  Project       : Toolbox
//  Workpackage   : libASR 
//
//               Copyright (C) 2023, ...
//            Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
//                       German Aerospace Center
//
//       Institut fuer Flugfuehrung/Institute of Flight Guidance
//              Tel. +49 531 295 2501, Fax: +49 531 295 2550
//                 WWW: http://www.bs.dlr.de/FL/
//
//  These coded instructions, statements, and computer programs contain
//  unpublished proprietary information of the German Aerospace Center
//  and are protected by the copyright law. They may not be disclosed to
//  third parties or copied or duplicated in any form,in whole or in part,
//  without the prior written consent of the German Aerospace Center


/*!
\file StringUtil.h
\brief Emulation of String Utilities outside DLR environment 
\author Hartmut Helmke (HHe)

\date 2023-07-08 HHe: first version

*/

#pragma once
#ifndef StringUtilHeader
#define StringUtilHeader
#include <vector>
#include <string>
#include <fstream>
#include <unordered_set>

namespace libutil
{

   inline std::ostream& operator<<(std::ostream& str, const std::vector<std::string>& v);
   inline std::ostream& operator<<(std::ostream& str,
      const std::unordered_set<std::string>& ar_strSet);

   inline std::ostream& operator<<(std::ostream& str, const std::vector<std::string>& v)
   {
      std::string blank = "";
      for (auto iter : v)
      {
         str << blank << iter;
         blank = " ";
      }
      return str;
   }


   inline std::ostream& operator<<(std::ostream& str, const std::unordered_set<std::string>& ar_strSet)
   {
      bool firstTime = true;
      for (const auto& iter : ar_strSet)
      {
         if (firstTime)
         {
            str << iter;
            firstTime = false;
         }
         else
         {
            str << std::string("\n     ") << iter;
         }
      }
      return str;
   }



}

#endif /* StringUtilHeader */
